# Generated by Django 3.2.7 on 2022-03-03 09:58

from django.db import migrations, models
import django.db.models.deletion
import time_stamped_model.models


class Migration(migrations.Migration):

    dependencies = [
        ('advanced_report_builder', '0004_customreport'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='kanbanreportlane',
            options={'ordering': ('order',)},
        ),
        migrations.RemoveField(
            model_name='kanbanreportlane',
            name='description',
        ),
        migrations.AddField(
            model_name='kanbanreportlane',
            name='background_colour_field',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='kanbanreportlane',
            name='heading_colour_field',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='kanbanreportlane',
            name='multiple_end_period',
            field=models.PositiveSmallIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='kanbanreportlane',
            name='multiple_start_period',
            field=models.PositiveSmallIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='kanbanreportlane',
            name='multiple_type',
            field=models.PositiveIntegerField(choices=[(0, 'N/A'), (1, 'Daily (single date)'), (2, 'Daily (within two date)'), (3, 'Weekly (single date)'), (4, 'Weekly (within two date)'), (5, 'Monthly (single date)'), (6, 'Monthly (within two date)')], default=0),
        ),
        migrations.AddField(
            model_name='kanbanreportlane',
            name='multiple_type_date_field',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='kanbanreportlane',
            name='multiple_type_end_date_field',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='kanbanreportlane',
            name='multiple_type_label',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.CreateModel(
            name='KanbanReportDescription',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', time_stamped_model.models.CreationDateTimeField(auto_now_add=True)),
                ('modified', time_stamped_model.models.ModificationDateTimeField(auto_now=True)),
                ('name', models.CharField(max_length=200)),
                ('description', models.TextField(blank=True, null=True)),
                ('order', models.PositiveSmallIntegerField()),
                ('kanban_report', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='advanced_report_builder.kanbanreport')),
                ('report_type', models.ForeignKey(null=True, on_delete=django.db.models.deletion.PROTECT, to='advanced_report_builder.reporttype')),
            ],
            options={
                'ordering': ('order',),
            },
        ),
        migrations.AddField(
            model_name='kanbanreportlane',
            name='kanban_report_description',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='advanced_report_builder.kanbanreportdescription'),
        ),
    ]
