# Generated by Django 3.2.7 on 2022-04-04 11:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('advanced_report_builder', '0007_auto_20220322_1939'),
    ]

    operations = [
        migrations.AddField(
            model_name='target',
            name='default_percentage',
            field=models.FloatField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='target',
            name='colour',
            field=models.CharField(blank=True, help_text='The colour when it gets displayed on a report', max_length=10, null=True),
        ),
        migrations.AlterField(
            model_name='target',
            name='default_value',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
