# Generated by Django 3.2.7 on 2022-02-16 09:52

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('advanced_report_builder', '0003_auto_20220215_1219'),
    ]

    operations = [
        migrations.CreateModel(
            name='CustomReport',
            fields=[
                ('report_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='advanced_report_builder.report')),
                ('output_type', models.CharField(blank=True, max_length=200, null=True)),
                ('view_name', models.CharField(max_length=200)),
                ('settings', models.JSONField(blank=True, null=True)),
            ],
            options={
                'abstract': False,
            },
            bases=('advanced_report_builder.report',),
        ),
    ]
